EmissionModel

Enum EmissionModel 

pub enum EmissionModel {
    Discrete {
        probabilities: Vec<Vec<f64>>,
    },
    Gaussian {
        means: Vec<f64>,
        variances: Vec<f64>,
        variance_floor: f64,
    },
}
Discrete or scalar Gaussian emissions for a finite hidden-state model.

Variants



Discrete

A row-stochastic categorical distribution for every hidden state.

Fields

probabilities: Vec<Vec<f64>>

State-major probability rows over symbols 0..symbol_count.



Gaussian

One univariate Gaussian distribution for every hidden state.

Fields

means: Vec<f64>

Mean for each hidden state.

variances: Vec<f64>

Strictly positive variance for each hidden state.

variance_floor: f64

Fitting floor retained with the model as numerical policy.

Implementations

Source

impl EmissionModel

pub fn symbol_count(&self) -> Option<usize>

Returns the number of categorical symbols, or None for Gaussian emissions.

pub fn discrete_probabilities(&self) -> Option<&[Vec<f64>]>

Returns the state-major categorical rows, when this is a discrete model.

pub fn gaussian_parameters(&self) -> Option<(&[f64], &[f64], f64)>

Returns Gaussian means, variances, and variance floor when applicable.