TransitionError

Enum TransitionError 

pub enum TransitionError {
    EmptyStates,
    DuplicateState {
        index: usize,
    },
    RowCount {
        expected: usize,
        actual: usize,
    },
    ColumnCount {
        row: usize,
        expected: usize,
        actual: usize,
    },
    InvalidProbability {
        distribution: &'static str,
        row: usize,
        column: usize,
        value: f64,
    },
    ProbabilityMass {
        distribution: &'static str,
        row: usize,
        sum: f64,
    },
}
Failure while constructing a finite row-stochastic transition matrix.

Variants



EmptyStates

No states were supplied.



DuplicateState

A state duplicated an earlier state.

Fields

index: usize

Position of the duplicate.



RowCount

The matrix row count did not match the state count.

Fields

expected: usize

Required row count.

actual: usize

Supplied row count.



ColumnCount

A row length did not match the state count.

Fields

row: usize

Zero-based row index.

expected: usize

Required column count.

actual: usize

Supplied column count.



InvalidProbability

A probability was non-finite or negative.

Fields

distribution: &'static str

Stable matrix or distribution name.

row: usize

Zero-based row index.

column: usize

Zero-based column index.

value: f64

Rejected probability.



ProbabilityMass

A probability row did not sum to one.

Fields

distribution: &'static str

Stable matrix or distribution name.

row: usize

Zero-based row index.

sum: f64

Observed probability mass.