pub struct StatsClaimEvidence { /* private fields */ }Expand description
Evidence carried by a descriptive statistics Claim.
Implementations
Sourceimpl StatsClaimEvidence
impl StatsClaimEvidence
Sourcepub fn new(metric: Symbol, inputs: Vec<f64>, value: f64) -> Self
pub fn new(metric: Symbol, inputs: Vec<f64>, value: f64) -> Self
Creates descriptive metric evidence from validated inputs and a result.
Sourcepub fn inputs(&self) -> &[f64]
pub fn inputs(&self) -> &[f64]
Returns the input samples or probabilities used to compute the metric.
Sourcepub fn table_value(&self, factory: &dyn Factory) -> Result<Value>
pub fn table_value(&self, factory: &dyn Factory) -> Result<Value>
Returns the evidence as a browsable runtime table.