pub type StatsResult<T> = Result<T, StatsError>;Expand description
Result alias for the statistics helpers, fixing the error to StatsError.
Aliased Type
pub enum StatsResult<T> {
Ok(T),
Err(StatsError),
}pub type StatsResult<T> = Result<T, StatsError>;Result alias for the statistics helpers, fixing the error to StatsError.
pub enum StatsResult<T> {
Ok(T),
Err(StatsError),
}